/*
 *	fhist - file history and comparison tools
 *	Copyright (C) 2000, 2002, 2004 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for common/input/file.c
 */

#ifndef COMMON_INPUT_FILE_H
#define COMMON_INPUT_FILE_H

#include <ac/stddef.h>
#include <ac/sys/stat.h>

#include <input.h>

input_ty *input_file_open(const char *);
void input_file_unlink_on_close(input_ty *);

#endif /* COMMON_INPUT_FILE_H */
